
	REM *****************************************************************************
	REM AutoCams.setup.bat                                             **************
	REM
	REM This script sets up the environment for running autocams related scripts.
	REM 
	REM It sets some useful variables that can be used as macros, such as
	REM bat_return, bat_PROMPT, etc.  Also, there are some variables that autocams
	REM needs to assume are set in order to run - such as bat_exedir and bat_exedrive.
	REM
	rem called like this:
	rem   	call "%~dp0AutoCams.setup.bat" "%~f0"
	rem Where: "%~f0" is used to make the bat_logfile_name=%~nx1
	rem        bat_batchfile=!bat_logfile_name!
	rem

:SETUP
	set bat_return=exit /b
	set return=!bat_return!

		REM *****************************************************************************
		REM **********        bat_COMMENT_BEGIN and bat_COMMENT_END               *******
		REM 
		rem Use them for commenting out entire statement blocks.  It cannot
		REM span across parts of statement blocks
		rem
		rem Note: These MUST be used with the %% tags and not the 
		rem       !! tags.
		rem
	
	set bat_COMMENT_BEGIN=if defined bat_COMMENTBLOCK (& REM 
	set bat_COMMENT_END=)& REM 

%bat_COMMENT_BEGIN%
	echo xxxxxxxxxxxxxxxxxxxxxxx
%bat_COMMENT_END%

	set bat_exedir=%~dp0::&						rem f:\CAMS\::
	set bat_exedir=!bat_exedir:\::=!&			rem f:\CAMS
	set bat_exedir=!bat_exedir:::=!&			rem f:\CAMS
	set bat_exedrive=!bat_exedir:~0,2!&			rem f:

	
	(echo.!bat_exedir!|find /i "\RunFolder">nul: 2>&1) && (
		CALL :PARSEDIR "!bat_exedir!"
		set bat_camsdir=!bat_retval1!
		set bat_camsdrive=!bat_camsdir:~0,2!
		set bat_startlocation=!bat_camsdir!
	) || (
		rem The cams dir is the "..\CAMS" dir.
		set bat_camsdir=!bat_exedir!
		set bat_startlocation=!bat_camsdir!
	)
	
		REM Allow scripts to run from under a queue dir, such as "d:\cams2_queue\RunFolder". 
	(echo.!bat_exedir!|find /i "queue">nul: 2>&1) || (
		
		if /i "!bat_startlocation:~-5!" neq "\CAMS" (
			!bat_echolog! '     [autocams.setup.bat] ERROR: You must start from x:\CAMS directory. 
			exit /b 1
		)
	)
	


	IF EXIST "!bat_exedir!\Cams_nonUS\FTP_Reprocess.exe" (
		set bat_exedir_nonUS="!bat_exedir!\Cams_nonUS"
	) ELSE (
		set bat_exedir_nonUS="!bat_exedir!"
	)
	
	

		REM *****************************************************************************
		REM **********           bat_PROMPT and bat_PAUSE                         *******
		REM
		REM bat_PROMPT is a macro used to display a simple prompt and it always returns the 
		REM entered value in the bat_choice variable.  If the value is "", then
		REM the user pressed ENTER without typing anything.  Entering: ddd   will 
		REM cause it to call the bat_PAUSE macro for debugging.  
		REM
		REM bat_PAUSE is a macro used to 
		REM *****************************************************************************

	set bat_PAUSE=call "!bat_exedir!\indent_pause.bat"
	set bat_PROMPT=call "!bat_exedir!\indent_prompt.bat"

		REM *****************************************************************************
		REM **********           BAT_TITLE                                        *******
		REM This new TITLE feature of autocams automatically displays in the Title bar of the 
		REM command window that name of the script that is running along with its entire
		REM command line argument list.  This now happens automatically with every script
		REM that calls this AutoCams.setup.bat "%~dpnx0" %* in the SETUP section of the script.
		REM
		REM It can be overridden by using the DOS TITLE command and it can be restored by 
		rem just using !bat_TITLE! again.  
		REM 
		REM !bat_TITLECLEAR! blanks the title out.
		REM
		REM !bat_TITLEWAIT! is also useful for notifying the user that a routine will
		REM take some time.  You'd use that like this:
		REM
		REM    !bat_TITLEWAIT!&		REM changes the title bar to "Wait..."
		REM    call "routine that takes a long time..."
		REM    !bat_TITLE!&			REM restores the title back
		REM
		REM The new TITLE feature needs to have a way to restore the title upone returning from
		REM a called routine.  Problem is, we need to save the errorlevel value from the routine 
		REM before anything reseting the !bat_TITLE!
		REM *****************************************************************************
		
	set bat_TITLE_string=[%~nx1] %*
	set bat_TITLE=call "!bat_exedir!\indent_title.bat" 
	set bat_TITLEWAIT=TITLE [%~nx1] Wait... 
	set bat_TITLECLEAR=set bat_TITLE_string=&TITLE.

	!bat_TITLE!
	
	set bat_CALL=CALL "!bat_exedir!\indent_call.bat" 
	set bat_CALLecho=CALL "!bat_exedir!\indent_callecho.bat" 

	set bat_WAIT=call "!bat_exedir!\autocams.WAIT.bat" 
	set bat_TIMEOUT=call "!bat_exedir!\autocams.TIMEOUT.bat" 
	set bat_START=call "!bat_exedir!\autocams.START.bat" 

		REM ********************************************************************
		REM Deal with the Logging...
		REM ********************************************************************

	if not defined bat_logdir (
		rem echo.~~~~~~~~~~~~~~~~~~~~~changing bat_logdir from "!bat_logdir!" to "!bat_camsdir!\Logs"
		set bat_logdir=!bat_camsdir!\Logs
	)
	
	if not exist "!bat_logdir!" (
		rem set bat_logdir=!bat_camsdir!\Logs
		rem echo.
		rem echo.
		rem echo.
		rem echo.
		rem echo.   [autocams.setup.bat]  creating the following log dir: "!bat_logdir!"
		md "!bat_logdir!"
	)

	set bat_batchfile=%~nx1
	set bat_logfile_name=!bat_batchfile!.log
	set bat_logfile=!bat_logdir!\!bat_logfile_name!
	set bat_logfile_full=!bat_logdir!\AutoCams_full.log
	
	if not exist "!bat_logdir!" (
		!bat_logexeclog! md "!bat_logdir!"
	)

	if /i "%~2" equ "/v" (
		echo.!bat_pushstring!AutoCams.setup.bat - %~nx0 %*
		echo.!bat_pushstring!AutoCams.setup.bat - bat_exedir="!bat_exedir!"
		echo.!bat_pushstring!AutoCams.setup.bat - bat_logfile="!bat_logfile!"`
		echo.!bat_pushstring!!bat_batchfile! CALL "!bat_exedir!\AutoCams.setup.bat" %*
		echo.[!date:~-10! !time!] !bat_pushstring!!bat_batchfile! CALL "!bat_exedir!\AutoCams.setup.bat" %*>>"!bat_logfile!"
	)
	
	set bat_AutoCams_lock_full=!bat_camsdir!\Temp\~autocams_busy.txt
	set bat_RemoteSession_Busy_lock_full=!bat_camsdir!\Temp\~RemoteSession_Busy.txt

:SETUP_END
EXIT /B

:PARSEDIR
        set bat_retval1=%~dp1::
        set bat_retval1=!bat_retval1:\::=!
        set bat_retval1=!bat_retval1:::=!

        set bat_retval2=%~nx1

:PARSEDIR_END
exit /b


:WAIT [IN seconds IN string)
	echo.%~2
	TIMEOUT /T %~1
exit /b
